cdmeta-package: cdmeta: Confidence-Distribution-Based Inference for...

cdmeta-packageR Documentation

cdmeta: Confidence-Distribution-Based Inference for Random-Effects Meta-Analysis

Description

Computational tools for confidence-distribution-propagation-based inference in random-effects meta-analysis. The package provides prediction intervals for the effect in a future study and interval estimation for the overall mean effect and heterogeneity measures.

Details

The main function is cdmeta. Forest plots are produced by the exported S3 generic forest, which dispatches to forest.cdmeta for objects of class "cdmeta".

Author(s)

Maintainer: Hisashi Noma noma@ism.ac.jp (ORCID)

Authors:

References

Higgins, J. P. T., Thompson, S. G., and Spiegelhalter, D. J. (2009). A re-evaluation of random-effects meta-analysis. Journal of the Royal Statistical Society: Series A, 172(1), 137–159. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/j.1467-985X.2008.00552.x")}

Noma, H., and Schwarzer, G. (2026). Frequentist prediction intervals for random-effects meta-analysis via confidence-distribution propagation. arXiv, 2608.26527. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2608.26527")}

Partlett, C., and Riley, R. D. (2017). Random effects meta-analysis: Coverage performance of 95 percent confidence and prediction intervals following REML estimation. Statistics in Medicine, 36(2), 301–317. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/sim.7140")}

Viechtbauer, W. (2010). Conducting meta-analyses in R with the metafor package. Journal of Statistical Software, 36(3), 1–48. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v036.i03")}

See Also

cdmeta, forest.cdmeta


cdmeta documentation built on Sept. 15, 2026, 5:09 p.m.